package com.gic.udesk.web.controller;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.ano.IgnoreLogin;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.utils.ResultControllerUtils;
import com.gic.udesk.constant.AgentPermissionEnum;
import com.gic.udesk.constant.CalculateResultTypeEnum;
import com.gic.udesk.constant.CustomFieldContentTypeEnum;
import com.gic.udesk.constant.CustomerPermissionEnum;
import com.gic.udesk.service.UdeskBaseApiService;

@RestController
public class GicTicketController {
    private static final Logger LOGGER = LogManager.getLogger(GicTicketController.class);

    @Autowired
    private UdeskBaseApiService udeskBaseApiService;

    @RequestMapping("/get-gic-service-select")
    @IgnoreLogin
    public RestResponse getGicServiceSelect() {
        return ResultControllerUtils.commonResult(udeskBaseApiService.getGicServiceSelect());
    }

    /**
     * 获取工单模板的自定义字段
     * @param type 1：gic基础业务 2：应用
     * @return
     */
    @RequestMapping("/get-custom-field-by-type")
    @IgnoreLogin
    public RestResponse getCustomFieldFromUdeskTemplates(Integer type) {
        return ResultControllerUtils.commonResult(udeskBaseApiService.getCustomFieldFromUdeskTemplates(type));
    }

    @RequestMapping("/ticket-upload-file")
    @IgnoreLogin
    public RestResponse getCustomFieldFromUdeskTemplates(HttpServletRequest request) throws Exception {
        String ticketId = request.getParameter("ticketId");
        if (!StringUtils.isNumeric(ticketId)) {
            return RestResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "工单ID错误，数值非法");
        }
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        //上传一个文件处理方式，如果是多个，用getFiles
        MultipartFile file = multipartRequest.getFile("file");
        if (file.isEmpty()) {
            return RestResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "文件为空");
        }
        ServiceResponse<String> result = udeskBaseApiService.ticketUploadFile(file.getBytes(), file.getOriginalFilename(),
                Integer.parseInt(ticketId));
        return ResultControllerUtils.commonResult(result);
    }

    /**
     * udesk自定义字段 客服权限
     * @return
     */
    @RequestMapping("/agent-permission-enum")
    @IgnoreLogin
    public RestResponse agentPermissionEnum() {
        return RestResponse.success(AgentPermissionEnum.list());
    }

    /**
     * udesk自定义字段 计算字段的计算结果类型
     * @return
     */
    @RequestMapping("/calculate-result-type-enum")
    @IgnoreLogin
    public RestResponse calculateResultTypeEnum() {
        return RestResponse.success(CalculateResultTypeEnum.list());
    }

    /**
     * udesk自定义字段 客户权限
     * @return
     */
    @RequestMapping("/custom-permission-enum")
    @IgnoreLogin
    public RestResponse customPermissionEnum() {
        return RestResponse.success(CustomerPermissionEnum.list());
    }

    /**
     * udesk自定义字段 字段类型
     * @return
     */
    @RequestMapping("/custom-field-content-type-enum")
    @IgnoreLogin
    public RestResponse customFieldContentTypeEnum() {
        return RestResponse.success(CustomFieldContentTypeEnum.list());
    }

}
